@@ -8,6 +8,9 @@ import numpy
 import pyfits
 import cpl
 
+recipe_name = 'rtest'
+raw_tag = 'RRRECIPE_DOCATG_RAW'
+
 class CplTestCase(unittest.TestCase):
     def setUp(self):
         cpl.Recipe.path = os.path.dirname(os.path.abspath(__file__))
@@ -16,16 +19,15 @@ class RecipeTestCase(CplTestCase):
     def setUp(self):
         CplTestCase.setUp(self)
         self.temp_dir = tempfile.mkdtemp()
-        self.recipe = cpl.Recipe('rrrecipe')
+        self.recipe = cpl.Recipe(recipe_name)
         self.recipe.temp_dir = self.temp_dir
-        self.recipe.tag = 'RRRECIPE_DOCATG_RAW'
+        self.recipe.tag = raw_tag
         self.image_size = (16, 16)
         self.raw_frame = pyfits.HDUList([
                 pyfits.PrimaryHDU(numpy.random.random_integers(0, 65000,
                                                                self.image_size))])
         self.raw_frame[0].header.update('HIERARCH ESO DET DIT', 0.0)
-        self.raw_frame[0].header.update('HIERARCH ESO PRO CATG', 
-                                        'RRRECIPE_DOCATG_RAW')
+        self.raw_frame[0].header.update('HIERARCH ESO PRO CATG', raw_tag)
 
     def tearDown(self):
         shutil.rmtree(self.temp_dir)
@@ -36,16 +38,16 @@ class RecipeStatic(CplTestCase):
         l = cpl.Recipe.list()
         self.assertTrue(isinstance(l, list))
         self.assertEqual(len(l), 1)
-        self.assertEqual(l[0], ('rrrecipe', ['0.0.1']))
+        self.assertEqual(l[0], (recipe_name, ['0.0.1']))
 
     def test_create_recipe(self):
         '''Create a recipe specified by its name'''
-        recipe = cpl.Recipe('rrrecipe')
+        recipe = cpl.Recipe(recipe_name)
         self.assertTrue(isinstance(recipe, cpl.Recipe))
 
     def test_create_recipe_version(self):
         '''Create a recipe specified by its name and version'''
-        recipe = cpl.Recipe('rrrecipe', version = '0.0.1')
+        recipe = cpl.Recipe(recipe_name, version = '0.0.1')
         self.assertTrue(isinstance(recipe, cpl.Recipe))        
 
     def test_create_recipe_wrong_name(self):
@@ -54,34 +56,34 @@ class RecipeStatic(CplTestCase):
 
     def test_create_recipe_wrong_version(self):
         '''Create a recipe specified by a wrong version'''
-        self.assertRaises(IOError, cpl.Recipe, 'rrrecipe', version='0.0.10')
+        self.assertRaises(IOError, cpl.Recipe, recipe_name, version='0.0.10')
 
     def test_create_recipe_filename(self):
         '''Create a recipe specified by a the name and the filename'''
-        recipe = cpl.Recipe('rrrecipe', filename = os.path.join(
+        recipe = cpl.Recipe(recipe_name, filename = os.path.join(
                 os.path.dirname(os.path.abspath(__file__)),
-                'iiinstrumentp', 'recipes', '.libs', 'rrrecipe.so'))
+                'iiinstrumentp', 'recipes', '.libs', 'rtest.so'))
         self.assertTrue(isinstance(recipe, cpl.Recipe))
 
     def test_create_recipe_wrong_filename(self):
         '''Create a recipe specified by a wrong filename'''
-        self.assertRaises(IOError, cpl.Recipe, 'rrrecipe', 
+        self.assertRaises(IOError, cpl.Recipe, recipe_name, 
                           filename = os.path.join(
                 os.path.dirname(os.path.abspath(__file__)),
-                'iiinstrumentp', 'recipes', '.libs', 'rrrecipe.o'))
+                'iiinstrumentp', 'recipes', '.libs', 'rtest.o'))
 
 class RecipeCommon(RecipeTestCase):
     def test_name(self):
         '''Recipe name'''
-        self.assertEqual(self.recipe.__name__, 'rrrecipe')
+        self.assertEqual(self.recipe.__name__, recipe_name)
 
     def test_author(self):
         '''Author attribute'''
-        self.assertEqual(self.recipe.__author__, 'Firstname Lastname')
+        self.assertEqual(self.recipe.__author__, 'Ole Streicher')
 
     def test_email(self):
         '''Author attribute'''
-        self.assertEqual(self.recipe.__email__, 'flastname@eso.org')
+        self.assertEqual(self.recipe.__email__, 'python-cpl@liska.ath.cx')
 
     def test_description(self):
         '''Synopsis and description'''
@@ -101,7 +103,7 @@ class RecipeParams(RecipeTestCase):
         self.assertTrue(isinstance(self.recipe.param.stropt, cpl.Parameter))
         self.assertEqual(self.recipe.param.stropt.name, 'stropt')
         self.assertEqual(self.recipe.param.stropt.context, 
-                         'iiinstrument.rrrecipe')
+                         'iiinstrument.rtest')
         self.assertEqual(self.recipe.param.stropt.default, None)
         self.assertEqual(self.recipe.param.stropt.value, None)
         self.assertEqual(self.recipe.param.stropt.range, None)
@@ -177,14 +179,16 @@ class RecipeParams(RecipeTestCase):
         self.assertEqual(self.recipe.param.boolopt, 
                          self.recipe.param['boolopt'])
         self.assertEqual(self.recipe.param.boolopt, 
-                         self.recipe.param['iiinstrument.rrrecipe.bool_option'])
+                         self.recipe.param['iiinstrument.rtest.bool_option'])
 
     def test_dotted_par(self):
         '''Use a parameter that has a dot in its alias'''
-        self.assertEqual(self.recipe.param.dot_opt, 
+        self.assertEqual(self.recipe.param.dot.opt,
+                         self.recipe.param.dot['opt'])
+        self.assertEqual(self.recipe.param.dot.opt,
                          self.recipe.param['dot.opt'])
-        self.assertEqual(self.recipe.param.dot_opt, 
-                         self.recipe.param['iiinstrument.rrrecipe.dotted.opt'])
+        self.assertEqual(self.recipe.param.dot.opt,
+                         self.recipe.param['iiinstrument.rtest.dotted.opt'])
 
     def test_iterate(self):
         '''Iteration over all parameters'''
@@ -206,9 +210,9 @@ class RecipeParams(RecipeTestCase):
         self.assertEqual(self.recipe.param.boolopt.value, False)
 
         # Check that we can assign a dictionary with the long names
-        self.recipe.param = { 'iiinstrument.rrrecipe.string_option':'dless', 
-                      'iiinstrument.rrrecipe.float_option':1.5, 
-                      'iiinstrument.rrrecipe.bool_option':True }
+        self.recipe.param = { 'iiinstrument.rtest.string_option':'dless', 
+                      'iiinstrument.rtest.float_option':1.5, 
+                      'iiinstrument.rtest.bool_option':True }
         self.assertEqual(self.recipe.param.stropt.value, 'dless')
         self.assertEqual(self.recipe.param.floatopt.value, 1.5)
         self.assertEqual(self.recipe.param.boolopt.value, True)
@@ -225,8 +229,11 @@ class RecipeParams(RecipeTestCase):
         '''[TAB] completition. 
         This requires to have   the __dir__() method working.
         '''
-        self.assertEqual(self.recipe.param.__dir__(), 
-                         [ p.name.replace('.','_') for p in self.recipe.param ])
+        self.assertEqual(set(self.recipe.param.__dir__()),
+                         set(p.name if '.' not in p.name
+                             else p.name.split('.', 1)[0]
+                             for p in self.recipe.param
+                             ))
 
 class RecipeCalib(RecipeTestCase):
     def test_set(self):
@@ -270,20 +277,10 @@ class RecipeExec(RecipeTestCase):
                 pyfits.PrimaryHDU(numpy.random.random_integers(0, 65000,
                                                                self.image_size))])
 
-    def test_frames_keyword(self):
-        '''Raw and calibration frames specified as keywords'''
-        self.recipe.tag = None
-        res = self.recipe(raw_RRRECIPE_DOCATG_RAW = self.raw_frame, 
-                          calib_FLAT = self.flat_frame)
-        self.assertTrue(isinstance(res, cpl.Result))
-        self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, pyfits.HDUList))
-        self.assertTrue(abs(self.raw_frame[0].data 
-                            - res.THE_PRO_CATG_VALUE[0].data).max() == 0)
-
     def test_frames_keyword_dict(self):
         '''Raw and calibration frames specified as keyword dict'''
         self.recipe.tag = None
-        res = self.recipe(raw_RRRECIPE_DOCATG_RAW = self.raw_frame, 
+        res = self.recipe(raw = {'RRRECIPE_DOCATG_RAW': self.raw_frame },
                           calib = { 'FLAT':self.flat_frame })
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, pyfits.HDUList))
@@ -294,7 +291,7 @@ class RecipeExec(RecipeTestCase):
         '''Raw frame specified as keyword, calibration frame set in recipe'''
         self.recipe.tag = None
         self.recipe.calib.FLAT = self.flat_frame
-        res = self.recipe(raw_RRRECIPE_DOCATG_RAW = self.raw_frame)
+        res = self.recipe({'RRRECIPE_DOCATG_RAW':self.raw_frame})
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, pyfits.HDUList))
 
@@ -302,13 +299,13 @@ class RecipeExec(RecipeTestCase):
         '''The 'tag' parameter'''
         self.recipe.tag = None
         self.recipe.calib.FLAT = self.flat_frame
-        res = self.recipe(self.raw_frame, tag = 'RRRECIPE_DOCATG_RAW')
+        res = self.recipe(self.raw_frame, tag = raw_tag)
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, pyfits.HDUList))
 
     def test_frames_tag_attribute(self):
         '''The 'tag' attribute'''
-        self.recipe.tag = 'RRRECIPE_DOCATG_RAW'
+        self.recipe.tag = raw_tag
         res = self.recipe(self.raw_frame)
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, pyfits.HDUList))
@@ -337,7 +334,7 @@ class RecipeExec(RecipeTestCase):
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, str))
         self.assertEqual(os.path.basename(res.THE_PRO_CATG_VALUE), 
-                         'rrrecipe.fits')
+                         'rtest.fits')
         self.assertTrue(os.path.isdir(output_dir))
         self.assertTrue(os.path.isfile(res.THE_PRO_CATG_VALUE))
         hdu = pyfits.open(res.THE_PRO_CATG_VALUE)
@@ -353,23 +350,22 @@ class RecipeExec(RecipeTestCase):
         self.assertTrue(isinstance(res, cpl.Result))
         self.assertTrue(isinstance(res.THE_PRO_CATG_VALUE, str))
         self.assertEqual(os.path.basename(res.THE_PRO_CATG_VALUE), 
-                         'rrrecipe.fits')
+                         'rtest.fits')
         self.assertTrue(os.path.isfile(res.THE_PRO_CATG_VALUE))
         hdu = pyfits.open(res.THE_PRO_CATG_VALUE)
         self.assertTrue(isinstance(hdu, pyfits.HDUList))
 
-    def test_param_keyword(self):
-        '''Parameter handling via keyword arg'''
-        res = self.recipe(self.raw_frame, 
-                          param_stropt = 'more').THE_PRO_CATG_VALUE
-        self.assertEqual(res[0].header['HIERARCH ESO QC STROPT'], 'more')
-
     def test_param_keyword_dict(self):
         '''Parameter handling via keyword dict'''
         res = self.recipe(self.raw_frame, 
                           param = { 'stropt':'more' }).THE_PRO_CATG_VALUE
         self.assertEqual(res[0].header['HIERARCH ESO QC STROPT'], 'more')
 
+    def test_param_keyword_dict_wrong(self):
+        '''Parameter handling via keyword dict'''
+        self.assertRaises(KeyError, self.recipe,
+                          self.raw_frame, param = { 'wrong':True })
+
     def test_param_setting(self):
         '''Parameter handling via recipe setting'''
         self.recipe.param.stropt = 'more'
@@ -387,7 +383,7 @@ class RecipeExec(RecipeTestCase):
     def test_param_overwrite(self):
         '''Overwrite the recipe setting param via via keyword arg'''
         self.recipe.param.stropt = 'more'
-        res = self.recipe(self.raw_frame, param_stropt = 'less').THE_PRO_CATG_VALUE
+        res = self.recipe(self.raw_frame, param = {'stropt':'less'}).THE_PRO_CATG_VALUE
         self.assertEqual(res[0].header['HIERARCH ESO QC STROPT'], 'less')
 
     def test_param_types(self):
@@ -406,37 +402,31 @@ class RecipeExec(RecipeTestCase):
         self.assertEqual(res[0].header['HIERARCH ESO QC ENUMOPT'], 'third')
         self.assertEqual(res[0].header['HIERARCH ESO QC RANGEOPT'], 0.125)
         
+    def test_environment_setting(self):
+        '''Additional environment parameter via recipe setting'''
+        self.recipe.env['TESTENV'] = 'unkk'
+        res = self.recipe(self.raw_frame).THE_PRO_CATG_VALUE
+        self.assertEqual(res[0].header['HIERARCH ESO QC TESTENV'], 'unkk')
+
+    def test_environment_keyword(self):
+        '''Additional environment parameter via recipe call keyword'''
+        res = self.recipe(self.raw_frame, 
+                          env = {'TESTENV':'kknu'}).THE_PRO_CATG_VALUE
+        self.assertEqual(res[0].header['HIERARCH ESO QC TESTENV'], 'kknu')
+
     def test_error(self):
         '''Error handling'''
         self.recipe.tag = 'some_unknown_tag'
         self.assertRaises(cpl.CplError, self.recipe, self.raw_frame)
 
-    def test_corrupted(self):
-        '''Handling of recipe crashes because of corrupted memory'''
-        self.recipe.param.crashing = 'free'
-        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
-
-    def test_segfault(self):
-        '''Handling of recipe crashes because of segmentation fault'''
-        self.recipe.param.crashing = 'segfault'
-        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
-
-    def test_cleanup_after_crash(self):
-        '''Test that a second run after a crash will succeed'''
-        output_dir = os.path.join(self.temp_dir, 'out')
-        self.recipe.output_dir = output_dir
-        self.recipe.param.crashing = 'segfault'
-        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
-        del self.recipe.param.crashing 
-        self.recipe(self.raw_frame)
-
     def test_parallel(self):
         '''Parallel execution'''
         results = list()
         for i in range(20):
             # mark each frame so that we can see their order
             self.raw_frame[0].header.update('HIERARCH ESO RAW1 NR', i)
-            results.append(self.recipe(self.raw_frame, param_intopt = i,
+            results.append(self.recipe(self.raw_frame, param = {'intopt':i},
+                                       env = {'TESTENV':('knu%02i' % i)},
                                        threaded = True))
         for i, res in enumerate(results):
             # check if we got the correct type
@@ -444,6 +434,9 @@ class RecipeExec(RecipeTestCase):
             # check if we have the correct parameter
             self.assertEqual(res.THE_PRO_CATG_VALUE[0].header[
                     'HIERARCH ESO QC INTOPT'], i)
+            # check if we have the correct environment
+            self.assertEqual(res.THE_PRO_CATG_VALUE[0].header[
+                    'HIERARCH ESO QC TESTENV'], ('knu%02i' % i))
             # check if we have the correct input frame
             self.assertEqual(res.THE_PRO_CATG_VALUE[0].header[
                     'HIERARCH ESO RAW1 NR'], i)
@@ -461,7 +454,7 @@ class RecipeExec(RecipeTestCase):
 
     def test_md5sum_result(self):
         '''MD5sum of the result file'''
-        self.recipe.tag = 'RRRECIPE_DOCATG_RAW'
+        self.recipe.tag = raw_tag
         res = self.recipe(self.raw_frame)
         key = 'DATAMD5'
         md5sum = res.THE_PRO_CATG_VALUE[0].header[key]
@@ -471,7 +464,7 @@ class RecipeExec(RecipeTestCase):
 
     def test_md5sum_calib(self):
         '''Created MD5sum for a HDUList calib file'''
-        self.recipe.tag = 'RRRECIPE_DOCATG_RAW'
+        self.recipe.tag = raw_tag
         self.recipe.calib.FLAT = self.flat_frame
         res = self.recipe(self.raw_frame)
         key = 'HIERARCH ESO PRO REC1 CAL1 DATAMD5'
@@ -480,6 +473,26 @@ class RecipeExec(RecipeTestCase):
         self.assertEqual(len(md5sum), 
                          len('9d123996fa9a7bda315d07e063043454'))
 
+class RecipeCrashing(RecipeTestCase):
+    def test_corrupted(self):
+        '''Handling of recipe crashes because of corrupted memory'''
+        self.recipe.param.crashing = 'free'
+        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
+
+    def test_segfault(self):
+        '''Handling of recipe crashes because of segmentation fault'''
+        self.recipe.param.crashing = 'segfault'
+        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
+
+    def test_cleanup_after_crash(self):
+        '''Test that a second run after a crash will succeed'''
+        output_dir = os.path.join(self.temp_dir, 'out')
+        self.recipe.output_dir = output_dir
+        self.recipe.param.crashing = 'segfault'
+        self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
+        del self.recipe.param.crashing
+        self.recipe(self.raw_frame)
+
 class RecipeRes(RecipeTestCase):
     def setUp(self):
         RecipeTestCase.setUp(self)
@@ -506,9 +519,15 @@ class RecipeRes(RecipeTestCase):
             self.assertTrue(isinstance(hdu, pyfits.HDUList))
 
 class RecipeEsorex(CplTestCase):
+    def setUp(self):
+        CplTestCase.setUp(self)
+        self.temp_dir = tempfile.mkdtemp()
+
     def tearDown(self):
         CplTestCase.tearDown(self)
-        cpl.msg.level = cpl.msg.OFF
+        cpl.esorex.msg.level = cpl.esorex.msg.OFF
+        cpl.esorex.log.level = cpl.esorex.msg.OFF
+        shutil.rmtree(self.temp_dir)
 
     def test_read_sof(self):
         '''Read a SOF file'''
@@ -536,23 +555,45 @@ class RecipeEsorex(CplTestCase):
         
     def test_esorex_init(self):
         '''Init CPL from an esorex.rc file'''
-        rcfile = 'esorex.caller.recipe-dir=/some/dir\n' \
-        'esorex.caller.msg-level=debug'
+        rcfile = '''esorex.caller.recipe-dir=/some/dir
+        esorex.caller.msg-level=debug
+        esorex.caller.log-level=info
+        esorex.caller.log-dir=%s
+        esorex.caller.log-file=some.log''' % self.temp_dir
         cpl.esorex.init(rcfile)
-        self.assertEqual(cpl.msg.level, cpl.msg.DEBUG)
+        self.assertEqual(cpl.esorex.msg.level, cpl.esorex.msg.DEBUG)
+        self.assertEqual(cpl.esorex.log.level, cpl.esorex.msg.INFO)
+        self.assertEqual(cpl.esorex.log.dir, self.temp_dir)
+        self.assertEqual(cpl.esorex.log.filename, 'some.log')
         self.assertEqual(cpl.Recipe.path, ['/some/dir'])
 
+    def test_esorex_log(self):
+        '''Write a logfile controlled by the convienence logger'''
+        dirname = os.path.join(self.temp_dir, 'log')
+        filename = 'python-cpl.log'
+        log_msg = 'Esorex convienence log'
+        os.mkdir(dirname)
+        cpl.esorex.log.dir = dirname
+        cpl.esorex.log.filename = filename
+        cpl.esorex.log.level = cpl.esorex.log.INFO
+        filename = os.path.join(dirname, filename)
+        logging.getLogger('cpl').info(log_msg)
+        self.assertTrue(os.path.exists(filename))
+        log_content = open(filename).read()
+        self.assertTrue(log_msg in log_content)
+        self.assertTrue('INFO' in log_content)
+
 class RecipeLog(RecipeTestCase):
     def setUp(self):
         RecipeTestCase.setUp(self)
         self.handler = RecipeLog.THandler()
-        logging.getLogger('cpl.rrrecipe').addHandler(self.handler)
+        logging.getLogger('cpl.rtest').addHandler(self.handler)
         self.other_handler = RecipeLog.THandler()
         logging.getLogger('othername').addHandler(self.other_handler)
 
     def tearDown(self):
         RecipeTestCase.tearDown(self)
-        logging.getLogger('cpl.rrrecipe').removeHandler(self.handler)
+        logging.getLogger('cpl.rtest').removeHandler(self.handler)
         logging.getLogger('othername').removeHandler(self.other_handler)
 
     class THandler(logging.Handler):
@@ -568,6 +609,7 @@ class RecipeLog(RecipeTestCase):
 
     def test_logging_DEBUG(self):
         '''Injection of CPL messages into the python logging system'''
+        self.handler.clear()
         logging.getLogger().setLevel(logging.DEBUG)
         self.recipe(self.raw_frame)
 
@@ -586,12 +628,12 @@ class RecipeLog(RecipeTestCase):
             lognames.add(r.name)
         # Check that we had at least one expected entry
         self.assertTrue('cpl_dfs_product_save' in funcnames)
-        self.assertTrue('cpl.rrrecipe.cpl_dfs_product_save' in lognames)
+        self.assertTrue('cpl.rtest.cpl_dfs_product_save' in lognames)
         
     def test_logging_INFO(self):
         '''Filtering INFO messages'''
         self.handler.clear()
-        logging.getLogger('cpl.rrrecipe').setLevel(logging.INFO)
+        logging.getLogger('cpl.rtest').setLevel(logging.INFO)
         self.recipe(self.raw_frame)
         # check that the logs are not empty
         self.assertNotEqual(len(self.handler.logs), 0)
@@ -599,7 +641,7 @@ class RecipeLog(RecipeTestCase):
     def test_logging_WARN(self):
         '''Filtering WARN messages'''
         self.handler.clear()
-        logging.getLogger('cpl.rrrecipe').setLevel(logging.WARN)
+        logging.getLogger('cpl.rtest').setLevel(logging.WARN)
         self.recipe(self.raw_frame)
         # check that the logs are not empty
         self.assertNotEqual(len(self.handler.logs), 0)
@@ -608,7 +650,7 @@ class RecipeLog(RecipeTestCase):
         '''Filtering of error messages'''
         # There is no error msg written by the recipe, so it should be empty.
         self.handler.clear()
-        logging.getLogger('cpl.rrrecipe').setLevel(logging.ERROR)
+        logging.getLogger('cpl.rtest').setLevel(logging.ERROR)
         self.recipe(self.raw_frame)
         self.assertEqual(len(self.handler.logs), 0)
 
@@ -619,6 +661,22 @@ class RecipeLog(RecipeTestCase):
         self.recipe(self.raw_frame, logname = 'othername')
         self.assertNotEqual(len(self.other_handler.logs), 0)
 
+    def test_logging_multiline(self):
+        '''Multiple lines in messages'''
+        self.handler.clear()
+        logging.getLogger('cpl.rtest').setLevel(logging.INFO)
+        self.recipe(self.raw_frame)
+        # check that the multi line log sequence appears
+        multiline = 0
+        tag = 'multiline#'
+        for l in self.handler.logs:
+            if tag not in l.msg:
+                continue
+            i = int(l.msg[l.msg.index(tag)+len(tag):].split()[0])
+            self.assertEqual(multiline + 1, i)
+            multiline = i
+        self.assertEqual(multiline, 3)
+
     def test_result(self):
         '''"log" attribute of the result object'''
         res = self.recipe(self.raw_frame)
@@ -706,7 +764,7 @@ class ProcessingInfo(RecipeTestCase):
     def test_version(self):
         '''Version information'''
         self.assertEqual(self.pinfo.version[0], self.recipe.version[0])
-        self.assertEqual(self.pinfo.cpl_version, 'cpl-%s' % cpl.lib_version)
+        self.assertEqual(self.pinfo.cpl_version, 'cpl-%s' % self.recipe.cpl_version)
 
     def test_md5(self):
         '''MD5 checksums'''
